@@ -4,7 +4,10 @@
 from __future__ import absolute_import
 # import models into model package
 from opera.api.openapi.models.csar_initialization_input import CsarInitializationInput
+from opera.api.openapi.models.csar_validation_input import CsarValidationInput
 from opera.api.openapi.models.deployment_input import DeploymentInput
+from opera.api.openapi.models.diff import Diff
+from opera.api.openapi.models.diff_request import DiffRequest
 from opera.api.openapi.models.info import Info
 from opera.api.openapi.models.invocation import Invocation
 from opera.api.openapi.models.invocation_state import InvocationState
@@ -14,4 +17,5 @@ from opera.api.openapi.models.packaging_format import PackagingFormat
 from opera.api.openapi.models.packaging_input import PackagingInput
 from opera.api.openapi.models.packaging_result import PackagingResult
 from opera.api.openapi.models.unpackaging_input import UnpackagingInput
+from opera.api.openapi.models.update_request import UpdateRequest
 from opera.api.openapi.models.validation_result import ValidationResult
